torchelie.datasets
==================

.. currentmodule:: torchelie.datasets

Debug datasets
~~~~~~~~~~~~~~

.. autosummary::
   :toctree: generated
   :template: klass.rst
   :nosignatures:

   ColoredColumns
   ColoredRows
   MS1M
   Pix2PixDataset

Loaders
~~~~~~~

.. autosummary::
   :toctree: generated
   :template: klass.rst
   :nosignatures:

   FastImageFolder
   UnlabeledImages
   ImagesPaths
   SideBySideImagePairsDataset

Datasets wrappers
~~~~~~~~~~~~~~~~~

.. autosummary::
   :toctree: generated
   :template: klass.rst
   :nosignatures:

   PairedDataset
   RandomPairsDataset
   MixUpDataset
   Subset
   NoexceptDataset
   WithIndexDataset
   CachedDataset
   HorizontalConcatDataset
   MergedDataset

Functions
~~~~~~~~~

.. autofunction:: torchelie.datasets.mixup
